@@ -1,7 +1,18 @@
 from django.db import models
-from .user import User
+
+from .work_order import WorkOrder
 from .base import BaseModelAbstract
-from .work_order_service import WorkOrderService
+
+TYPES = (
+    ('wallet-topup', 'wallet-topup'),
+    ('wallet-withdrawal', 'wallet-withdrawal'),
+    ('kyc-verification', 'kyc-verification'),
+    ('meter-vend', 'meter-vend'),
+    ('buy-meter', 'buy-meter'),
+    ('service-order-commitment', 'service-order-commitment'),
+    ('service-order-complete', 'service-order-complete'),
+    ('others', 'others'),
+)
 
 
 class TransactionLog(BaseModelAbstract, models.Model):
@@ -11,10 +22,8 @@ class TransactionLog(BaseModelAbstract, models.Model):
     paymentVendor = models.ForeignKey(
         "PaymentVendor", models.SET_NULL,
         blank=True, null=True)
-    service = models.ForeignKey(WorkOrderService, models.SET_NULL,
-                                blank=True, null=True)
-    serviceDescription = models.TextField(
-        db_column='serviceDescription', blank=True, null=True)
+    workOrder = models.ForeignKey(WorkOrder, models.SET_NULL,
+                                  blank=True, null=True)
     platform = models.CharField(max_length=30, blank=True, null=True)
     requestJson = models.JSONField(
         db_column='requestJSON', blank=True, null=True)
@@ -23,6 +32,7 @@ class TransactionLog(BaseModelAbstract, models.Model):
     amount = models.DecimalField(decimal_places=2, max_digits=15, default=0)
     isPaid = models.BooleanField(default=False) 
     status = models.CharField(max_length=30, blank=True, null=True)
+    transactionType = models.CharField(max_length=30, choices=TYPES)
     vendorStatus = models.CharField(max_length=30, blank=True, null=True)
     callbackJson = models.JSONField(db_column='callbackJSON', blank=True, 
                                     null=True)  # Field name made lowercase.
@@ -30,11 +40,6 @@ class TransactionLog(BaseModelAbstract, models.Model):
                                   null=True)  # Field name made lowercase.
     webhookJson = models.JSONField(db_column='webhookJSON', blank=True, 
                                    null=True)  # Field name made lowercase.
-    recipient = models.ForeignKey(User, models.SET_NULL, blank=True, 
-                                  null=True, 
-                                  related_name="received_transactions")
-    name = models.CharField(max_length=255, blank=True, null=True)
-    email = models.EmailField(blank=True, null=True)
 
     class Meta:
         db_table = 'TransactionLogs'
